@@ -2,7 +2,7 @@
 
 # MIT License
 #
-# Copyright 2018-2021 New York University Abu Dhabi
+# Copyright 2018-2022 New York University Abu Dhabi
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -385,7 +385,10 @@ class Analyzer:
             pass
 
         elif not _is_ar(word):
-            result = copy.copy(self._db.defaults['noun'])
+            # TODO: This is a temporary workaround until a 'foreign' entry is
+            # added to the databases.
+            result = copy.copy(self._db.defaults['latin'])
+            result['pos'] = 'foreign'
             result['diac'] = word
             result['stem'] = word
             result['stemgloss'] = word
